@@ -4,8 +4,19 @@
  * Refer to rpncalc.c for copyrights and license permissions.           *
  ************************************************************************/
 
-/* $Id: cmds.h,v 1.5 1997/09/11 21:21:01 david Rel $
+/* $Id: cmds.h,v 1.8 2000/04/02 16:11:21 david Rel $
  * $Log: cmds.h,v $
+ * Revision 1.8  2000/04/02 16:11:21  david
+ * Removed function prototype typedef and moved function prototype direct
+ * into struct cmd.
+ *
+ * Revision 1.7  1999/09/12 20:50:49  david
+ * Added constant and variable tables instead of functions.
+ * Added ip and fp.
+ *
+ * Revision 1.6  1999/03/06 14:41:20  david
+ * Added new commands.
+ *
  * Revision 1.5  1997/09/11 21:21:01  david
  * libc6: pow10 and pow2 are gone; use our own definitions.
  *
@@ -23,32 +34,31 @@
  *
  * Revision 1.0  1995/12/31 18:16:22  david
  * Initial revision
- * */
+ * 
+ */
 
-enum BASE { DEC, HEX, OCT, CHAR };	/* current base (dec,oct..) */
+#include <math.h>
 
-extern enum BASE base;
-extern int digits;			/* accuracy, number of digits */
+double rnd(void);
 
-double showstack(void);
-double pick(double elm);
-double depth(void);
-
-double pi(void);
-double e(void);
-
-#if linux && !libc5
-double pow10(double y);
 double pow2(double y);
-#endif
-
+double pow10(double y);
 double chs(double f);
+double sign(double f); 
 double sqr(double f);
 double inv(double f);
+double ip(double f);
 double log2(double f);
 double fact(double d);
+double fp(double f);
 double prec(double p);
 double not(double l);
+double sr(double l);
+double sl(double l);
+double srb(double l);
+double slb(double l);
+
+double rdz(double s);
 
 double plus(double s1, double s2);
 double minus(double s, double m);
@@ -64,5 +74,44 @@ double and(double l1, double l2);
 double or(double l1, double l2);
 double xor(double l1, double l2);
 
+double percent(double x, double y);
+double deltapercent(double x, double y);
+double percenttotal(double x, double y);
+
+double min(double x, double y);
+double max(double x, double y);
+
 double sum(void);
 double prod(void);
+
+struct cmd {
+  const char *fname;
+  const short argno;			/* 0..2: no of arguments */
+  short pushrestostack;
+  double (*fnct)();
+  const char  *helptext;
+};
+
+struct cnst {
+  const char   *vname;
+  const double  value;
+  const char   *helptext;
+};
+
+struct var {
+  const char   *vname;
+  double  value;
+  int   isconst;
+};
+
+const size_t noofconst;
+
+size_t noofvars;
+const size_t maxnoofvars;
+
+double help(struct cmd *f);
+double warranty(void);
+double quit(void);
+
+int cmdcmp(const void *f1, const void *f2);
+int varcmp(const void *f1, const void *f2);
