@@ -4,8 +4,14 @@
  * Refer to rpncalc.c for copyrights and license permissions.           *
  ************************************************************************/
 
-/* $Id: stack.c,v 1.6 1997/09/12 19:02:44 david Rel $
+/* $Id: stack.c,v 1.7 1999/03/06 14:42:04 david Rel $
  * $Log: stack.c,v $
+ * Revision 1.7  1999/03/06 14:42:04  david
+ * Added new commands: drop2, roll, rot.
+ * Fixed rot to act like the original.
+ * Internationalized.
+ * Autoconf'ed.
+ *
  * Revision 1.6  1997/09/12 19:02:44  david
  * Clearer cleanup of linked list,
  * marking ^? explicitely as \127
@@ -48,16 +54,29 @@
 #endif
 #include <limits.h>
 
+#include "stack.h"
 #include "cmds.h"
 #include "utils.h"
-#include "stack.h"
 
-struct elm *anchor=NULL;
+#ifdef HAVE_GETTEXT
+#include <libintl.h>
 
+#define  _(String) gettext(String)
+#else
+#define  _(String) (String)
+#endif
+
+static struct elm *anchor=NULL;
 int pushtostack=1;
 
-enum BASE base=DEC;
-int digits=3;			/* accuracy, number of digits */
+static enum BASE base=DEC;
+static int digits=3;			/* accuracy, number of digits */
+
+double prec(double p)
+{
+  digits=ceil(p); pushtostack=0;
+  return 0.0; /* dummy value */
+}
 
 /* Push an element on the stack */
 double push(double elem)
@@ -90,8 +109,8 @@ double pop(void)
   }
   else
   {
-    fprintf(stderr, "pop: stack empty.\n"); value=0.0; 
-    pushtostack=0;
+    fprintf(stderr, _("pop: stack empty.\n"));
+    value=0.0; pushtostack=0;
   }
   return value;
 }
@@ -108,7 +127,7 @@ double pick(double op1)
   if ((i==n) && (p!=NULL)) return p->value;
   else
   {
-    fprintf(stderr, "pick: element not available.\n"); 
+    fprintf(stderr, _("pick: element not available.\n")); 
     pushtostack=0;
     return 0.0;
   }
@@ -126,12 +145,28 @@ double drop(void)
   }
   else
   {
-    fprintf(stderr, "drop: stack empty.\n"); pushtostack=0;
+    fprintf(stderr, _("drop: stack empty.\n"));
+    pushtostack=0;
   }
 
   return 0.0; /* dummy value */
 }
 
+/* Drop top 2 elements */
+double drop2(void)
+{
+  (void)drop(); (void)drop();
+  return 0.0; /* dummy value */
+}
+
+double dropn(double n)
+{
+  long int i;
+
+  for (i=1; i<=(long int)n; i++) (void)drop();
+  return 0.0; /* dummy value */
+}
+
 /* Duplicate top element */
 double dupel(double d)
 {
@@ -154,14 +189,6 @@ double dupn(double n, double d)
   return 0.0; /* dummy value */
 }
 
-double dropn(double n)
-{
-  long int i;
-
-  for (i=1; i<=(long int)n; i++) (void)drop();
-  return 0.0; /* dummy value */
-}
-
 double clear(void)
 {
   struct elm *p, *t;
@@ -205,14 +232,14 @@ double swap(void)
   return 0.0; /* dummy value */
 }
 
-/* Roll top three elements: 1 2 3 -> 3 1 2 */
-double roll(void)
+/* Roll top three elements: 1 2 3 -> 2 3 1 */
+double rot(void)
 {
   double tmp1, tmp2, tmp3;
 
-  tmp1 = pop(); tmp2 = pop(); tmp3 = pop();
+  tmp3 = pop(); tmp2 = pop(); tmp1 = pop();
   
-  (void)push(tmp1); (void)push(tmp3); (void)push(tmp2);
+  (void)push(tmp2); (void)push(tmp3); (void)push(tmp1);
   return 0.0; /* dummy value */
 }
 
