@@ -4,8 +4,12 @@
  * Refer to rpncalc.c for copyrights and license permissions.           *
  ************************************************************************/
 
-/* $Id: utils.c,v 1.5 1998/01/03 22:57:39 david Exp $
+/* $Id: utils.c,v 1.6 1999/03/06 14:35:17 david Rel $
  * $Log: utils.c,v $
+ * Revision 1.6  1999/03/06 14:35:17  david
+ * Internationalized.
+ * Removed lint comments.
+ *
  * Revision 1.5  1998/01/03 22:57:39  david
  * replaced HAVE_READLINE with HAVE_LIBREADLINE (for autoconf)
  *
@@ -34,41 +38,50 @@
 #include <strings.h>
 
 #include "utils.h"
+#include "config.h"
 
 #ifdef HAVE_LIBREADLINE
 #include <readline/readline.h>
 #include <readline/history.h>
 #endif
 
+#ifdef HAVE_GETTEXT
+#include <libintl.h>
+
+#define _(String) gettext(String)
+#else
+#define _(String) (String)
+#define textdomain(Domain)
+#define bindtextdomain(Package, Directory)
+#endif
+
 #define LINEFRAGMENT 32
 
-/*@out@*/ void *xmalloc(size_t size)	/* safe malloc */
+void *xmalloc(size_t size)	/* safe malloc */
 {
   void *ptr;
 
   ptr=malloc(size);
-  if (ptr == NULL) 
-  {
-    perror("Out of memory!"); 
+  if (ptr == NULL) {
+    perror(_("Out of memory!")); 
     exit(1); 
   }
 
   return ptr;
 }
 
-/*@out@*/ void *xrealloc(void *ptr, size_t size)	/* save realloc */
+void *xrealloc(void *ptr, size_t size)	/* save realloc */
 {
   ptr=realloc(ptr, size);
-  if (ptr == NULL) 
-  {
-    perror("Out of memory!"); 
+  if (ptr == NULL) {
+    perror(_("Out of memory!")); 
     exit(1); 
   }
 
   return ptr;
 }
 
-char *dupstr(const char *s)
+char *xstrdup(const char *s)
 {
   char *r;
 
@@ -77,33 +90,29 @@ char *dupstr(const char *s)
   return (r);
 }
 
-/*@null@*/ char *getline(void)
+#ifndef HAVE_READLINE
+char *readline(char *prompt)
 /* Read a line of text without imposing an length limit.
    If we readline support is compiled in, use the readline function. */
 {
   char *line=NULL;
-#ifndef HAVE_LIBREADLINE
-  int c;
-  int i;
-#endif
+  int c, i;
 
-#ifdef HAVE_LIBREADLINE
-  line=(char *)readline(""); 
-#else
   i=0; line=(char *)xmalloc((size_t)(LINEFRAGMENT+1));
-  while (((c = getc(stdin)) != EOF) && (c != '\n') && (c != '\0'))
-  {
-   if ((i > LINEFRAGMENT) &&  (i % LINEFRAGMENT) == 0) 
-     line=(char *)xrealloc(line,(size_t)(LINEFRAGMENT+1));
-   line[i]=(char)c; i++;
+  while (((c = getc(stdin)) != EOF) && (c != '\n') && (c != '\0')) {
+    if ((i > LINEFRAGMENT) &&  (i % LINEFRAGMENT) == 0) {
+      line=(char *)xrealloc(line,(size_t)(LINEFRAGMENT+1));
+    }
+    line[i]=(char)c; i++;
   }
-  if ((c != EOF) && (c != '\0')) line[i]='\0';
-  else
-  {
-    free(line); line=NULL;   /* this is readline compatible; 
-				return NULL when the input line is empty */
+  if ((c != EOF) && (c != '\0')) {
+    line[i]='\0';
+  } else {
+    free(line); 
+    line=NULL;   /* this is readline compatible; 
+		    return NULL when the input line is empty */
   }
-#endif
 
   return line;
 }
+#endif
